@@ -3,6 +3,7 @@
 """Console script for porerefiner."""
 import sys, os
 import click
+import yaml
 
 from asyncio import run
 from pathlib import Path
@@ -12,22 +13,64 @@ from porerefiner.cli_utils import VALID_RUN_ID, server, hr_formatter, json_forma
 from porerefiner.samplesheets import load_from_csv, load_from_excel
 from porerefiner.protocols.porerefiner.rpc.porerefiner_pb2 import RunRequest, RunListRequest, RunAttachRequest, RunRsyncRequest, TagRequest
 
+# prfr front-end should no longer use the package config support, it needs to do its own thing
+
 # default_config = lambda: os.environ.get('POREREFINER_CONFIG', Path.home() / '.porerefiner' / 'config.yaml')
 
-def default_config():
-    path = Path(os.environ.get('POREREFINER_CONFIG', Path.home() / '.porerefiner' / 'config.yaml'))
-    if not path.exists():
-        path = Path("/etc/porerefiner/config.yaml")
-        if not path.exists():
-            from porerefiner.config import Config
-            socket_path = click.prompt('path to porerefiner server socket?', default=Path('/etc/porerefiner/porerefiner.sock'), show_default=True)
-            Config.new_config_file(path, client_only=True, socket_path=socket_path)
-    return path
+# def default_config():
+#     path = Path(os.environ.get('POREREFINER_CONFIG', Path.home() / '.porerefiner' / 'config.yaml'))
+#     if not path.exists():
+#         path = Path("/etc/porerefiner/config.yaml")
+#         if not path.exists():
+#             from porerefiner.config import Config
+#             socket_path = click.prompt('path to porerefiner server socket?', default=Path('/etc/porerefiner/porerefiner.sock'), show_default=True)
+#             Config.new_config_file(path, client_only=True, socket_path=socket_path)
+#     return path
 
 
 
-with_config = click.option('--config', default=default_config(), help='Path to PoreRefiner config', show_default=True, metavar="PATH")
-with_remote = click.option('-c', '--connect-to', 'remote', default=None, help="Connect to specified remote host instead of configured local host.", metavar="HOST:PORT")
+# with_config = click.option('--config', default=default_config(), help='Path to PoreRefiner config', show_default=True, metavar="PATH")
+
+central_config = Path('/etc/porerefiner/config.yaml')
+user_config = Path.home() / '.porerefiner' / 'config.yaml'
+default_socket = '/etc/porerefiner/porerefiner.sock'
+default_use_ssl = False
+
+if user_config.exists():
+    with open(user_config, 'r') as config:
+        config = yaml.safe_load(config)
+    default_socket = config['server']['socket']
+    default_use_ssl = config['server']['use_ssl']
+elif central_config.exists():
+    with open(central_config, 'r') as config:
+        config = yaml.safe_load(config)
+    default_socket = config['server']['socket']
+    default_use_ssl = config['server']['use_ssl']
+
+# with_remote = click.option('-c', '--connect-to', 'remote', default=default_socket, show_default=True, help="Connect to specified remote host instead of configured local host.", metavar="HOST:PORT")(
+#     click.option('--ssl/--no-ssl', 'use_ssl', default=default_use_ssl, show_default=True)
+# )
+
+def with_remote(cmd):
+    cmd = click.option('-c', '--connect-to', 'remote', default=default_socket, show_default=True, help="Connect to specified remote host instead of configured local host.", metavar="HOST:PORT")(cmd)
+    cmd = click.option('--ssl/--no-ssl', 'use_ssl', default=default_use_ssl, show_default=True)(cmd)
+    return cmd
+    
+
+# with_output_formatting = click.option('-h', '--human-readable', 'output_format', flag_value=hr_formatter, help='Output in a human-readable table.', default=hr_formatter)(
+#     click.option('-j', '--json', 'output_format', flag_value=json_formatter, help='Output in JSON.')(
+#         click.option('-x', '--xml', 'output_format', flag_value=xml_formatter, help='Output in schemaless XML.')(
+#             click.option('-e', '--extended', 'extend', default=False, is_flag=True, help="Extended output format.")
+#         )
+#     )
+# )
+
+def with_output_formatting(cmd):
+    cmd = click.option('-h', '--human-readable', 'output_format', flag_value=hr_formatter, help='Output in a human-readable table.', default=hr_formatter)(cmd)
+    cmd = click.option('-j', '--json', 'output_format', flag_value=json_formatter, help='Output in JSON.')(cmd)
+    cmd = click.option('-x', '--xml', 'output_format', flag_value=xml_formatter, help='Output in schemaless XML.')(cmd)
+    cmd = click.option('-e', '--extended', 'extend', default=False, is_flag=True, help="Extended output format.")(cmd)
+    return cmd
 
 def coroutine(func):
     "Coroutine runner"
@@ -38,24 +81,25 @@ def coroutine(func):
 
 @click.group()
 def cli():
-    """Command line interface for PoreRefiner, a Nanopore run manager."""
+    """Command line interface for Porerefiner, a Nanopore run manager."""
     pass #pragma: no cover
 
 
 @cli.command()
 @handle_connection_errors
-@with_config
+#@with_config
 @with_remote
 @click.option('-a', '--all', is_flag=True, default=False, help="Show finished and ongoing runs.")
-@click.option('-h', '--human-readable', 'output_format', flag_value=hr_formatter, help='Output in a human-readable table.', default=hr_formatter)
-@click.option('-j', '--json', 'output_format', flag_value=json_formatter, help='Output in JSON.')
-@click.option('-x', '--xml', 'output_format', flag_value=xml_formatter, help='Output in schemaless XML.')
+# @click.option('-h', '--human-readable', 'output_format', flag_value=hr_formatter, help='Output in a human-readable table.', default=hr_formatter)
+# @click.option('-j', '--json', 'output_format', flag_value=json_formatter, help='Output in JSON.')
+# @click.option('-x', '--xml', 'output_format', flag_value=xml_formatter, help='Output in schemaless XML.')
+# @click.option('-e', '--extended', 'extend', default=False, is_flag=True, help="Extended output format.")
+@with_output_formatting
 @click.option('-t', '--tag', 'tags', multiple=True)
-@click.option('-e', '--extended', 'extend', default=False, is_flag=True, help="Extended output format.")
 @coroutine
-async def ps(config, remote, output_format, extend, all=False, tags=[]):
+async def ps(remote, output_format, extend, all=False, tags=[], use_ssl=False):
     "Show runs in progress, or every tracked run (--all), or with a particular tag (--tag)."
-    with server(config, remote) as serv:
+    with server(remote, use_ssl) as serv:
         with output_format(extend) as formatter:
             resp = await serv.GetRuns(RunListRequest(all=all, tags=tags))
             for run in resp.runs.runs:
@@ -63,16 +107,16 @@ async def ps(config, remote, output_format, extend, all=False, tags=[]):
 
 @cli.command()
 @handle_connection_errors
-@with_config
+#@with_config
 @with_remote
 @click.option('-h', '--human-readable', 'output_format', flag_value=hr_formatter, help='Output in a human-readable table.', default=hr_formatter)
 @click.option('-j', '--json', 'output_format', flag_value=json_formatter, help='Output in JSON.')
 @click.option('-x', '--xml', 'output_format', flag_value=xml_formatter, help='Output in schemaless XML.')
 @click.argument('run_id', type=VALID_RUN_ID)
 @coroutine
-async def info(config, remote, output_format, run_id):
+async def info(remote, output_format, run_id, use_ssl=False):
     "Return information about a run, historical or in progress."
-    with server(config, remote) as serv:
+    with server(remote, use_ssl) as serv:
         with output_format(extend=True) as formatter:
             req = RunRequest()
             if isinstance(run_id, str):
@@ -96,8 +140,8 @@ barcode_kits,
 sample_id,accession,barcode_id,organism,extraction_kit,comment,user
 """)
 
-async def tag_runner(config, remote, run_id, tags=[], untag=False):
-    with server(config, remote) as serv:
+async def tag_runner(remote, run_id, tags=[], untag=False, use_ssl=False):
+    with server(remote, use_ssl) as serv:
         req = RunRequest()
         if isinstance(run_id, str):
             req.name = run_id
@@ -113,7 +157,7 @@ async def tag_runner(config, remote, run_id, tags=[], untag=False):
 
 @cli.command()
 @handle_connection_errors
-@with_config
+#@with_config
 @with_remote
 @click.argument('run_id', type=VALID_RUN_ID)
 @click.argument('tag', type=click.STRING, nargs=-1)
@@ -124,7 +168,7 @@ def tag(config, remote, run_id, tag=[]):
 
 @cli.command()
 @handle_connection_errors
-@with_config
+#@with_config
 @with_remote
 @click.argument('run_id', type=VALID_RUN_ID)
 @click.argument('tag', type=click.STRING, nargs=-1)
@@ -134,12 +178,12 @@ def untag(config, remote, run_id, tag=[]):
 
 @cli.command()
 @handle_connection_errors
-@with_config
+#@with_config
 @with_remote
 @click.argument('samplesheet')
 @click.option('-r', '--run', 'run_id', type=VALID_RUN_ID, )
 @coroutine
-async def load(config, remote, samplesheet, run_id=None):
+async def load(remote, samplesheet, run_id=None, use_ssl=False):
     "Load a sample sheet to be attached to a run, or to the next run that is started."
     try:
         if '.csv' in samplesheet:
@@ -159,7 +203,7 @@ async def load(config, remote, samplesheet, run_id=None):
     except ImportError:
         click.echo(f"ERROR: OpenPyXL not installed; Excel files ({samplesheet}) can't be read. Use pip to install OpenPyXL.", err=True)
     else:
-        with server(config, remote) as serv:
+        with server(*remote) as serv:
             req = RunAttachRequest(sheet=ss)
             if isinstance(run_id, int):
                 req.id = run_id
@@ -172,7 +216,13 @@ async def load(config, remote, samplesheet, run_id=None):
             else:
                 click.echo(f"{samplesheet} loaded successfully.")
 
-@cli.command("test-plugins")
+@cli.group()
+def plugins():
+    "Commands relating to plugins."
+    pass
+
+
+@plugins.command("test")
 @click.argument('config_path', default='/etc/porerefiner/config.yaml')
 @coroutine
 async def test_plugins(config_path):
